==> 0.0.7.tar.gz: android/src/main/java/com/app/flutter/mtpl/flutter_test_selfiecapture/FlutterTestSelfiecapturePlugin.java <==
package com.app.flutter.mtpl.flutter_test_selfiecapture;

import android.app.Activity;
import android.content.Intent;
import android.util.Log;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * FlutterTestSelfiecapturePlugin
 */
public class FlutterTestSelfiecapturePlugin implements MethodCallHandler, PluginRegistry.ActivityResultListener {
    /**
     * Plugin registration.
     */

    Activity context;
    MethodChannel methodChannel;
    private Result result;

    public FlutterTestSelfiecapturePlugin(Activity activity, MethodChannel methodChannel) {
        this.context = activity;
        this.methodChannel = methodChannel;
        this.methodChannel.setMethodCallHandler(this);
    }

    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutter_test_selfiecapture");
        //channel.setMethodCallHandler(new FlutterTestSelfiecapturePlugin());
        channel.setMethodCallHandler(new FlutterTestSelfiecapturePlugin(registrar.activity(), channel));
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        if (call.method.equalsIgnoreCase("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equalsIgnoreCase("detectLiveliness")) {
            //this.result = result;
            result.success(detectLiveliness(context));
        } else {
            result.notImplemented();
        }
    }

    private Object detectLiveliness(Activity context) {
        Intent intent = new Intent(context, FaceTrackerActivity.class);
        context.startActivityForResult(intent, 100);
        return intent;
    }

    @Override
    public boolean onActivityResult(int requestCode, int resultCode, Intent data) {
        if (requestCode == 100) {
            if (resultCode == Activity.RESULT_OK) {
                String filePath = data.getStringExtra("filePath");
                Log.e("filePath.plugin", filePath);
                this.result.success(filePath);
            } else {
                /* String filePath = data.getStringExtra("filePath");
                 */
                this.result.error("", null, null);
            }
            return true;
        }
        return false;
    }
}

==> 0.0.8.tar.gz: android/src/main/java/com/app/flutter/mtpl/flutter_test_selfiecapture/FlutterTestSelfiecapturePlugin.java <==
package com.app.flutter.mtpl.flutter_test_selfiecapture;

import android.app.Activity;
import android.content.Intent;
import android.util.Log;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * FlutterTestSelfiecapturePlugin
 */
public class FlutterTestSelfiecapturePlugin implements MethodCallHandler, PluginRegistry.ActivityResultListener {
    /**
     * Plugin registration.
     */

    Activity context;
    MethodChannel methodChannel;
    private Result result;

    public FlutterTestSelfiecapturePlugin(Activity activity, MethodChannel methodChannel) {
        this.context = activity;
        this.methodChannel = methodChannel;
        this.methodChannel.setMethodCallHandler(this);
    }

    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutter_test_selfiecapture");
        //channel.setMethodCallHandler(new FlutterTestSelfiecapturePlugin());
        channel.setMethodCallHandler(new FlutterTestSelfiecapturePlugin(registrar.activity(), channel));
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        if (call.method.equalsIgnoreCase("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equalsIgnoreCase("detectLiveliness")) {
            //this.result = result;
            //result.success(detectLiveliness(context));
            detectLiveliness(context);
        } else {
            result.notImplemented();
        }
    }

    private void detectLiveliness(Activity context) {
        Intent intent = new Intent(context, FaceTrackerActivity.class);
        context.startActivityForResult(intent, 100);
    }

    @Override
    public boolean onActivityResult(int requestCode, int resultCode, Intent data) {
        if (requestCode == 100) {
            if (resultCode == Activity.RESULT_OK) {
                String filePath = data.getStringExtra("filePath");
                Log.e("filePath.plugin", filePath);
                this.result.success(filePath);
            } else {
                /* String filePath = data.getStringExtra("filePath");
                 */
                this.result.error("", null, null);
            }
            return true;
        }
        return false;
    }
}
